Index: trunk/ippTools/src/p2searchPendingFrames.c
===================================================================
--- trunk/ippTools/src/p2searchPendingFrames.c	(revision 8121)
+++ trunk/ippTools/src/p2searchPendingFrames.c	(revision 9057)
@@ -25,5 +25,5 @@
         p2PendingExpRow *exposure = exposures->data[i];
 
-        psMetadataAddStr(where, PS_LIST_TAIL, "exp_id", PS_META_REPLACE, "==", exposure->exp_id);
+        psMetadataAddStr(where, PS_LIST_TAIL, "exp_tag", PS_META_REPLACE, "==", exposure->exp_tag);
         psMetadataAddS32(where, PS_LIST_TAIL, "p2_version", PS_META_REPLACE, "==", exposure->p2_version);
 
@@ -61,18 +61,18 @@
     PS_ASSERT_PTR_NON_NULL(config, NULL);
 
-    // exp_id is optional
+    // exp_tag is optional
     bool status = false;
-    psString exp_id = psMetadataLookupStr(&status, config->args, "-exp_id");
+    psString exp_tag = psMetadataLookupStr(&status, config->args, "-exp_tag");
     if (!status) {
-        psError(PS_ERR_UNKNOWN, false, "failed to lookup value for -exp_id");
+        psError(PS_ERR_UNKNOWN, false, "failed to lookup value for -exp_tag");
         return false;
     }
 
     // search only based on exp_id -- either they specified it or not
     psMetadata *where = NULL;
-    if (exp_id) {
+    if (exp_tag) {
         where = psMetadataAlloc(); 
-        if (!psMetadataAddStr(where, PS_LIST_TAIL, "exp_id", 0, "==", exp_id)) {
-            psError(PS_ERR_UNKNOWN, false, "failed to add item exp_id");
+        if (!psMetadataAddStr(where, PS_LIST_TAIL, "exp_tag", 0, "==", exp_tag)) {
+            psError(PS_ERR_UNKNOWN, false, "failed to add item exp_tag");
             psFree(where);
             return false;
@@ -61,18 +61,18 @@
     }
 
-    // search only based on exp_id -- either they specified it or not
+    // search only based on exp_tag -- either they specified it or not
     psMetadata *where = NULL;
